@@ -29,10 +29,16 @@ setClass("XVectorList",
 ### GroupedIRanges methods.
 ###
 
+### Ugly workaround a serious callNextMethod inefficiency reported here:
+###   https://bugs.r-project.org/bugzilla/show_bug.cgi?id=16974
+.GroupedIRanges_parallelSlotNames <-
+    c("group", parallelSlotNames(new("IRanges")))
+
 ### Combine the new parallel slots with those of the parent class. Make sure
 ### to put the new parallel slots *first*.
 setMethod("parallelSlotNames", "GroupedIRanges",
-    function(x) c("group", callNextMethod())
+    #function(x) c("group", callNextMethod())
+    function(x) .GroupedIRanges_parallelSlotNames
 )
 
 .valid.GroupedIRanges <- function(x)
@@ -119,9 +125,9 @@ setReplaceMethod("names", "XVectorList",
     pool_len <- length(x@pool)
     if (pool_len == 0L)
         return(x)
-    remap <- high2low(sapply(x@pool@xp_list, address))
-    keep_idx <- which(is.na(remap))
-    remap[keep_idx] <- seq_len(length(keep_idx))
+    addr <- addresses(x@pool@xp_list)
+    keep_idx <- which(!duplicated(addr))
+    remap <- match(addr, addr[keep_idx])
     x@pool <- x@pool[keep_idx]
     x@ranges@group <- remap[x@ranges@group]
     x
@@ -264,12 +270,14 @@ setMethod("[[", "XVectorList",
 setMethod("extractROWS", "XVectorList",
     function(x, i)
     {
-        i <- extractROWS(setNames(seq_along(x), names(x)), i)
-        x@ranges <- extractROWS(x@ranges, i)
-        x@elementMetadata <- extractROWS(x@elementMetadata, i)
+        i <- normalizeSingleBracketSubscript(i, x, as.NSBS=TRUE)
+        ans_ranges <- extractROWS(x@ranges, i)
+        ans_mcols <- extractROWS(x@elementMetadata, i)
+        ans <- BiocGenerics:::replaceSlots(x, ranges=ans_ranges,
+                                              mcols=ans_mcols,
+                                              check=FALSE)
         ## Drop unused pool elements.
-        x <- .dropUnusedPoolElts(x)
-        x
+        .dropUnusedPoolElts(ans)
     }
 )
 
