@@ -13,6 +13,11 @@ static const R_CallMethodDef callMethods[] = {
 	CALLMETHOD_DEF(new_output_filexp, 4),
 	CALLMETHOD_DEF(finalize_filexp, 1),
 
+/* RDS_random_access.c */
+	CALLMETHOD_DEF(RDS_read_file, 3),
+	CALLMETHOD_DEF(RDS_extract_subvector, 2),
+	CALLMETHOD_DEF(RDS_extract_subarray, 3),
+
 /* SharedVector_class.c */
 	CALLMETHOD_DEF(get_object_address, 1),
 	CALLMETHOD_DEF(get_list_addresses, 1),
@@ -94,6 +99,7 @@ void R_init_XVector(DllInfo *info)
 	R_registerRoutines(info, NULL, callMethods, NULL, NULL);
 
 /* io_utils.c */
+	REGISTER_CCALLABLE(_filexp_read);
 	REGISTER_CCALLABLE(_filexp_gets);
 	REGISTER_CCALLABLE(_filexp_seek);
 	REGISTER_CCALLABLE(_filexp_rewind);
